@@ -15,13 +15,12 @@ from django.db import connection
 from django.utils.translation import gettext_lazy as _
 from django_celery_results.models import TaskResult
 
-from .. import layout
+from .. import layout, utils
 from ..layout.components import tabs
 from ..layout.components.button import Button
 from ..layout.components.datatable import DataTable, DataTableColumn
 from ..layout.components.forms import Form, FormField
 from ..layout.components.icon import Icon
-from ..utils import Link, aslayout
 from ..views import BrowseView
 
 R = layout.grid.Row
@@ -33,11 +32,15 @@ TD = layout.datatable.DataTableColumn
 
 
 @user_passes_test(lambda user: user.is_superuser)
-@aslayout
+@utils.aslayout
 def maintenancesettings(request):
     # Add the view's header
     ret = layout.grid.Grid(R(C(hg.H3(_("Maintenance")))), gutter=False)
 
+    restart_result = restart_app_server(request)
+    if not isinstance(restart_result, hg.BaseElement):
+        return restart_result
+
     # Add the Package Information modal
     ret.append(
         R(
@@ -50,6 +53,8 @@ def maintenancesettings(request):
                 maintenance_database_optimization(request),
                 hg.H4(_("Rebuild search index"), _style="margin-top: 3rem;"),
                 maintenance_search_reindex(request),
+                hg.H4(_("Restart application server"), _style="margin-top: 3rem;"),
+                restart_result,
             ),
         )
     )
@@ -57,7 +62,7 @@ def maintenancesettings(request):
     return ret
 
 
-@aslayout
+@utils.aslayout
 def componentpreview(request):
     class ConfigForm(forms.Form):
         with_label = forms.BooleanField(required=False)
@@ -152,7 +157,7 @@ def componentpreview(request):
             )
         ),
         layout.button.Button.from_link(
-            Link(href="#", label=_("Back to top")),
+            utils.Link(href="#", label=_("Back to top")),
             buttontype="secondary",
             icon="arrow--up",
             notext=True,
@@ -263,7 +268,7 @@ def componentpreview(request):
                                         button=(
                                             layout.components.button.Button("Button")
                                         ),
-                                        link=Link(href="#", label="link"),
+                                        link=utils.Link(href="#", label="link"),
                                     ),
                                 ),
                             ),
@@ -484,7 +489,31 @@ def maintenance_search_reindex(request):
     )
 
 
-@aslayout
+def restart_app_server(request):
+    class RestartForm(forms.Form):
+        pass
+
+    if request.method == "POST":
+        form = RestartForm(request.POST)
+        if form.is_valid():
+            messages.info(request, _("Restarted application server"))
+            return utils.HttpResponseRestartUWSGIServer(request.get_full_path())
+    else:
+        form = RestartForm()
+
+    return hg.BaseElement(
+        Form(
+            form,
+            Button(
+                _("Restart"),
+                type="submit",
+                style="margin-bottom: 1rem;",
+            ),
+        )
+    )
+
+
+@utils.aslayout
 def systeminformation(request):
     git_status = ""
     try:
